==> ZenTaoPMS.17.2.php7.0.zip: zentaopms/module/projectrelease/lang/en.php <==
<?php
/**
 * The release module zh-cn file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2020 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yuchun Li <liyuchun@cnezsoft.com>
 * @package     release
 * @version     $Id: zh-cn.php 4129 2020-11-27 01:58:14Z wwccss $
 * @link        http://www.zentao.net
 */
$lang->projectrelease->common           = 'Release';
$lang->projectrelease->create           = "Create Release";
$lang->projectrelease->edit             = "Edit Release";
$lang->projectrelease->linkStory        = "Link Story";
$lang->projectrelease->linkBug          = "Link Bug";
$lang->projectrelease->delete           = "Delete Release";
$lang->projectrelease->deleted          = 'Deleted';
$lang->projectrelease->view             = "Release Detail";
$lang->projectrelease->browse           = "Release List";
$lang->projectrelease->changeStatus     = "Change Status";
$lang->projectrelease->batchUnlink      = "Batch Unlink";
$lang->projectrelease->batchUnlinkStory = "Batch Unlink Stories";
$lang->projectrelease->batchUnlinkBug   = "Batch Unlink Bugs";
$lang->projectrelease->unlinkStory      = "Unlink {$lang->SRCommon}";
$lang->projectrelease->unlinkBug        = 'Unlink Bug';
$lang->projectrelease->export           = 'Export as HTML';
$lang->projectrelease->browseAction     = "Release List";
$lang->projectrelease->notify           = 'notify';

==> ZenTaoPMS.17.5.php5.4_5.6.zip: zentaopms/module/projectrelease/lang/en.php <==
<?php
/**
 * The release module zh-cn file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2020 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yuchun Li <liyuchun@cnezsoft.com>
 * @package     release
 * @version     $Id: zh-cn.php 4129 2020-11-27 01:58:14Z wwccss $
 * @link        http://www.zentao.net
 */
$lang->projectrelease->common           = 'Release';
$lang->projectrelease->create           = "Create Release";
$lang->projectrelease->edit             = "Edit Release";
$lang->projectrelease->linkStory        = "Link Story";
$lang->projectrelease->linkBug          = "Link Bug";
$lang->projectrelease->delete           = "Delete Release";
$lang->projectrelease->deleted          = 'Deleted';
$lang->projectrelease->view             = "Release Detail";
$lang->projectrelease->browse           = "Release List";
$lang->projectrelease->changeStatus     = "Change Status";
$lang->projectrelease->batchUnlink      = "Batch Unlink";
$lang->projectrelease->batchUnlinkStory = "Batch Unlink Stories";
$lang->projectrelease->batchUnlinkBug   = "Batch Unlink Bugs";
$lang->projectrelease->unlinkStory      = "Unlink {$lang->SRCommon}";
$lang->projectrelease->unlinkBug        = 'Unlink Bug';
$lang->projectrelease->export           = 'Export as HTML';
$lang->projectrelease->browseAction     = "Release List";
$lang->projectrelease->notify           = 'notify';

$lang->projectrelease->featureBar['browse']['all']       = 'All';
$lang->projectrelease->featureBar['browse']['normal']    = 'Active';
$lang->projectrelease->featureBar['browse']['terminate'] = 'Terminated';
